==> morepls_0.2.tar.gz: morepls/README.md <==
# **morepls** <img src="man/figures/morepls.png" height=140px width=120px alt="" align="right" />

## Interpretation tools for PLS regression

<!-- badges: start -->
[![R-CMD-check](https://framagit.org/nicolas-robette/morepls/badges/master/pipeline.svg)](https://framagit.org/nicolas-robette/morepls/-/commits/master)
[![](https://www.r-pkg.org/badges/version/morepls?color=blue)](https://cran.r-project.org/package=morepls)
[![](http://cranlogs.r-pkg.org/badges/last-month/morepls?color=orange)](https://cran.r-project.org/package=morepls)
<!-- badges: end -->

`morepls` provides functions for the interpretation of PLS regressions.

The documentation is available here: [https://nicolas-robette.frama.io/morepls/](https://nicolas-robette.frama.io/morepls/)

Graphical functions :

-   two-dimensional plot of observations
-   two-dimensional plot of correlations between variables and components
-   two-dimensional plot of variables (Y loadings and X projections)
-   two-dimensional plot of supplementary variables
-   two-dimensional plot of interaction between two supplementary variables
-   two-dimensional plot of main and partial effects of a supplementary variable
-   bar plot of regression coefficients
-   bar plot of X variables weights
-   bar plot of X variables VIPs

Statistical indicators :

-   correlations between variables and components
-   R2 and redundancies between variables and components
-   Q2 and cumulative Q2 indexes
-   raw and standardized coefficients


## Installation

Execute the following code within `R`:

``` r
if (!require(devtools)){
    install.packages('devtools')
    library(devtools)
}
install_git("https://framagit.org/nicolas-robette/morepls")
```


## References

Martens, H., Næs, T. (1989) *Multivariate calibration*. Chichester: Wiley.

Tenenhaus, M. (1998) *La Regression PLS. Théorie et Pratique*. Editions TECHNIP, Paris.

The image in the hex sticker is outrageously taken from [https://moreplease.com/](https://moreplease.com/) from Iain Merrick.

==> morepls_0.2.1.tar.gz: morepls/README.md <==
# **morepls** <img src="man/figures/morepls.png" height=140px width=120px alt="" align="right" />

## Interpretation tools for PLS regression

<!-- badges: start -->
[![R-CMD-check](https://framagit.org/nicolas-robette/morepls/badges/master/pipeline.svg?key_text=R+CMD+check&key_width=90)](https://framagit.org/nicolas-robette/morepls/-/commits/master)
[![](https://img.shields.io/gitlab/last-commit/nicolas-robette%2Fmorepls?gitlab_url=https%3A%2F%2Fframagit.org)](https://img.shields.io/gitlab/last-commit/nicolas-robette%2Fmorepls?gitlab_url=https%3A%2F%2Fframagit.org)
[![](https://www.r-pkg.org/badges/version/morepls?color=blue)](https://cran.r-project.org/package=morepls)
[![](https://www.r-pkg.org/badges/last-release/morepls?color=blue)](https://cran.r-project.org/package=morepls)
[![](https://img.shields.io/badge/DOI-10.32614/CRAN.package.morepls-1f57b6?style=flat&link=https://doi.org/10.32614/CRAN.package.morepls)](https://doi.org/10.32614/CRAN.package.morepls)
[![](http://cranlogs.r-pkg.org/badges/last-month/morepls?color=orange)](https://cran.r-project.org/package=morepls)
[![](http://cranlogs.r-pkg.org/badges/grand-total/morepls?color=orange)](https://cran.r-project.org/package=morepls)

<!-- badges: end -->

`morepls` provides functions for the interpretation of PLS regressions.

The documentation is available here: [https://nicolas-robette.frama.io/morepls/](https://nicolas-robette.frama.io/morepls/)

Graphical functions :

-   two-dimensional plot of observations
-   two-dimensional plot of correlations between variables and components
-   two-dimensional plot of variables (Y loadings and X projections)
-   two-dimensional plot of supplementary variables
-   two-dimensional plot of interaction between two supplementary variables
-   two-dimensional plot of main and partial effects of a supplementary variable
-   bar plot of regression coefficients
-   bar plot of X variables weights
-   bar plot of X variables VIPs

Statistical indicators :

-   correlations between variables and components
-   R2 and redundancies between variables and components
-   Q2 and cumulative Q2 indexes
-   raw and standardized coefficients


## Installation

Execute the following code within `R`:

``` r
if (!require(devtools)){
    install.packages('devtools')
    library(devtools)
}
install_git("https://framagit.org/nicolas-robette/morepls")
```


## Citation

To cite `morepls` in publications, use :

Robette N. (2025), *`morepls` : Interpretation tools for PLS regression in `R`*, version 0.2, https://nicolas-robette.frama.io/morepls/


## References

Martens, H., Næs, T. (1989) *Multivariate calibration*. Chichester: Wiley.

Tenenhaus, M. (1998) *La Regression PLS. Théorie et Pratique*. Editions TECHNIP, Paris.

The image in the hex sticker is outrageously taken from [https://moreplease.com/](https://moreplease.com/) from Iain Merrick.
